#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_EXPONENT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_EXPONENT_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/simd/exponent.hpp>

#endif
